/**
 * @file signals.c
 * @author Florian Schmitt <florian.schmitt@qikgrp.com>
 * ---------------------------------------------------------
 * (c) Florian Schmitt / Nov-2012 / All rights reserved. 
 * ---------------------------------------------------------
 * Catches signals
**/
#include <stdlib.h>
#include <syslog.h>
#include <signal.h>
#include <string.h>
#include "lindmxd.h"



/**
 * Catches a signal
 * This function is passed to signal(...) by main.c and
 * only called by system signals
**/
void signals_handle_sig(int sig)
{
	switch(sig)
	{
		/* urgent termination */
		case SIGKILL:
			syslog(LOG_NOTICE, "Catched %s signal", strsignal(sig));
			exit(EXIT_FAILURE);
		/* normal termination */
		case SIGTERM:
		case SIGQUIT:
		case SIGINT:
			syslog(LOG_NOTICE, "Catched %s signal", strsignal(sig));
			lindmxd_stop();
			/* lindmxd_stop does a successfull exit by itself */
			abort();
		default:
			syslog(LOG_NOTICE, "Catched an unimplemented signal '%s' (%d)", strsignal(sig), sig);
	}
	exit(EXIT_FAILURE);
}
